@@ -8,7 +8,8 @@ use icu_provider::DataError;
 #[cfg(feature = "std")]
 impl std::error::Error for PropertiesError {}
 
-#[derive(Display, Debug)]
+#[derive(Display, Debug, Copy, Clone)]
+#[non_exhaustive]
 pub enum PropertiesError {
     /// An error occurred while loading data
     #[displaydoc("{0}")]
@@ -16,9 +17,9 @@ pub enum PropertiesError {
     /// An unknown value was used for the [`Script`] property
     #[displaydoc("Unknown script id: {0}")]
     UnknownScriptId(u16),
-    /// An unknown value was used for the [`GeneralCategory`] property
-    #[displaydoc("Unknown general category set: {0}")]
-    UnknownGeneralCategorySet(u32),
+    /// An unknown value was used for the [`GeneralCategoryGroup`] property
+    #[displaydoc("Unknown general category group: {0}")]
+    UnknownGeneralCategoryGroup(u32),
 }
 
 impl From<DataError> for PropertiesError {
